model BuckConverter "Buck converter and Zener regulator comparison."
  parameter Modelica.Units.SI.Resistance r1 = 16 "Resistance for the load";
  parameter Modelica.Units.SI.Capacitance c1(displayUnit = "uF") = 4e-006 "Capacitance of the buck converter capacitor";
  parameter Modelica.Units.SI.Inductance l1(displayUnit = "mH") = 0.02 "Inductance of the buck converter inductor";
  parameter Modelica.Units.SI.Time T(displayUnit = "ms") = 5e-005 "Time for one period";
  parameter Real D = 12 / 24 "Duty-ratio";
  parameter Modelica.Units.SI.Voltage vin = 24 "Input voltage into the buck converter";
  Modelica.Electrical.Analog.Sources.ConstantVoltage voltage_BuckConverter(V = vin) annotation(Placement(visible = true, transformation(origin = {-80.058, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Resistor load_BuckConverter(R = r1) annotation(Placement(visible = true, transformation(origin = {80, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Capacitor capacitor_BuckConverter(C = c1) annotation(Placement(visible = true, transformation(origin = {40, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Inductor inductor_BuckConverter(L = l1) annotation(Placement(visible = true, transformation(origin = {20, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Electrical.Analog.Basic.Ground ground_BuckConverter annotation(Placement(visible = true, transformation(origin = {-100, 0}, extent = {{-10, -10}, {10, 10}}, rotation = -450)));
  Modelica.Blocks.Sources.BooleanPulse booleanPulse(period = T, width = D * 100) annotation(Placement(visible = true, transformation(origin = {-60, 70}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Electrical.Analog.Ideal.IdealDiode idealDiode_BuckConverter(Vknee = 0.04) annotation(Placement(visible = true, transformation(origin = {-0, 30}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
  Modelica.Electrical.Analog.Ideal.IdealClosingSwitch idealClosingSwitch annotation(Placement(visible = true, transformation(origin = {-40, 50}, extent = {{-10, -10}, {10, 10}}, rotation = 0)));
  Modelica.Electrical.Analog.Sources.ConstantVoltage voltage_Zener(V = vin) annotation(Placement(visible = true, transformation(origin = {-60, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Resistor load_Zener(R = r1) "Load attached to the circuit" annotation(Placement(visible = true, transformation(origin = {60, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -90)));
  Modelica.Electrical.Analog.Basic.Ground ground_Zener annotation(Placement(visible = true, transformation(origin = {-90, -80}, extent = {{-10, -10}, {10, 10}}, rotation = -450)));
  Modelica.Electrical.Analog.Basic.Resistor resistor_Zener(R = 11.94029851) annotation(Placement(visible = true, transformation(origin = {-30, -40}, extent = {{-10, -10}, {10, 10}}, rotation = -360)));
  Modelica.Electrical.Analog.Semiconductors.ZDiode diode_Zener(Bv = 12, Ibv = 0.005) annotation(Placement(visible = true, transformation(origin = {0, -60}, extent = {{-10, -10}, {10, 10}}, rotation = -270)));
equation
  connect(voltage_BuckConverter.n, ground_BuckConverter.p) annotation(Line(visible = true, origin = {-83.372, 6.667}, points = {{3.314, 13.333}, {3.314, -6.667}, {-6.628, -6.667}}, color = {10, 90, 224}));
  connect(capacitor_BuckConverter.n, voltage_BuckConverter.n) annotation(Line(visible = true, origin = {-15, 5}, points = {{55, 15}, {55, -5}, {-65.058, -5}, {-65.058, 15}}, color = {10, 90, 224}));
  connect(capacitor_BuckConverter.n, idealDiode_BuckConverter.p) annotation(Line(visible = true, origin = {22.5, 2.75}, points = {{17.5, 17.25}, {17.5, -2.75}, {-22.5, -2.75}, {-22.5, 17.25}}, color = {10, 90, 224}));
  connect(load_BuckConverter.n, voltage_BuckConverter.n) annotation(Line(visible = true, origin = {-5, 5}, points = {{85, 15}, {85, -5}, {-75, -5}, {-75.058, 15}}, color = {10, 90, 224}));
  connect(voltage_BuckConverter.p, idealClosingSwitch.p) annotation(Line(visible = true, origin = {-70.039, 46.667}, points = {{-10.019, -6.667}, {-10.019, 3.333}, {20.039, 3.333}}, color = {10, 90, 224}));
  connect(inductor_BuckConverter.n, load_BuckConverter.p) annotation(Line(visible = true, origin = {63.333, 46.667}, points = {{-33.333, 3.333}, {16.667, 3.333}, {16.667, -6.667}}, color = {10, 90, 224}));
  connect(inductor_BuckConverter.p, idealDiode_BuckConverter.n) annotation(Line(visible = true, origin = {3.333, 46.667}, points = {{6.667, 3.333}, {-3.333, 3.333}, {-3.333, -6.667}}, color = {10, 90, 224}));
  connect(booleanPulse.y, idealClosingSwitch.control) annotation(Line(visible = true, origin = {-37, 74.333}, points = {{-12, -4.333}, {-3, -4.333}, {-3, -17.333}}, color = {190, 52, 178}));
  connect(inductor_BuckConverter.p, idealClosingSwitch.n) annotation(Line(visible = true, origin = {-10, 50}, points = {{20, 0}, {-20, 0}}, color = {10, 90, 224}));
  connect(inductor_BuckConverter.n, capacitor_BuckConverter.p) annotation(Line(visible = true, origin = {40, 46.667}, points = {{-10, 3.333}, {0, 3.333}, {0, -6.667}}, color = {10, 90, 224}));
  connect(resistor_Zener.n, load_Zener.p) annotation(Line(visible = true, origin = {33.333, -43.333}, points = {{-53.333, 3.333}, {26.667, 3.333}, {26.667, -6.667}}, color = {10, 90, 224}));
  connect(resistor_Zener.n, diode_Zener.n) annotation(Line(visible = true, origin = {-6.667, -43.333}, points = {{-13.333, 3.333}, {6.667, 3.333}, {6.667, -6.667}}, color = {10, 90, 224}));
  connect(resistor_Zener.p, voltage_Zener.p) annotation(Line(visible = true, origin = {-53.333, -43.333}, points = {{13.333, 3.333}, {-6.667, 3.333}, {-6.667, -6.667}}, color = {10, 90, 224}));
  connect(diode_Zener.p, ground_Zener.p) annotation(Line(visible = true, origin = {-26.667, -76.667}, points = {{26.667, 6.667}, {26.667, -3.333}, {-53.333, -3.333}}, color = {10, 90, 224}));
  connect(load_Zener.n, voltage_Zener.n) annotation(Line(visible = true, origin = {0, -78.5}, points = {{60, 8.5}, {60, -1.5}, {-60, -1.5}, {-60, 8.5}}, color = {10, 90, 224}));
  connect(voltage_Zener.n, ground_Zener.p) annotation(Line(visible = true, origin = {-66.667, -76.667}, points = {{6.667, 6.667}, {6.667, -3.333}, {-13.333, -3.333}}, color = {10, 90, 224}));
  annotation(__Wolfram(openClass = BuckConverter, ControlPanels(Panel(identifier = "optimistic-pascal", title = "Model parameters", elements = {InputField(variable = D, label = "Duty-ratio"), InputField(variable = T, label = "Time for one period"), InputField(variable = c1, label = "Capacitance of the buck converter capacitor"), InputField(variable = l1, label = "Inductance of the buck converter inductor"), InputField(variable = r1, label = "Resistance for the load"), InputField(variable = vin, label = "Input voltage into the buck converter")}))), experiment(StopTime = 0.05, __Wolfram_SynchronizeWithRealTime = false), __Wolfram(PlotSet(plots = {Plot(name = "LoadVoltageBuckConvertervsZenerRegulator ", preferred = true, subPlots = {SubPlot(curves = {Curve(x = time, y = load_BuckConverter.v), Curve(x = time, y = load_Zener.v)})}), Plot(name = "BuckConverterBehavior", subPlots = {SubPlot(curves = {Curve(x = time, y = load_BuckConverter.v), Curve(x = time, y = load_Zener.v)}, range = Range(xmin = 0.007985104552499202, xmax = 0.008516085813714526, ymin = 11.9518475877193, ymax = 12.13411793372319)), SubPlot(curves = {Curve(x = time, y = booleanPulse.y)}, range = Range(xmin = 0.007985104552499202, xmax = 0.008516085813714526, ymin = auto, ymax = auto))})})), uses(Modelica(version = "4.0.0")), Documentation(info = "<html>
<p>Using a linear DC‐to‐DC regulator is one of the simplest ways to reduce the voltage of a DC supply. However, as linear regulators work by converting excess power to heat, they are highly inefficient and inconvenient to use in many applications. A common alternative to reduce DC voltage is instead to use a buck converter. In this example, we study the difference in efficiency between a buck converter and a simple (linear) Zener regulator when converting a supply voltage of 24 V to an output voltage of 12 V.</p>

<h4>Dynamics</h4>

<p>A buck converter is a switched-mode power supply that uses a <a href=\"modelica://Modelica.Electrical.Analog.Ideal.IdealClosingSwitch\">switch</a>, a <a href=\"modelica://Modelica.Electrical.Analog.Ideal.IdealDiode\">diode</a>, an <a href=\"modelica://Modelica.Electrical.Analog.Basic.Inductor\">inductor</a>, and a <a href=\"modelica://Modelica.Electrical.Analog.Basic.Capacitor\">capacitor</a> to convert direct current voltage from a higher to a lower level. When the switch is turned off, the inductor current freewheels through the diode. When the switch is turned on, the inductor current increases and doesn&rsquo;t pass through the diode.&nbsp;</p>

<h4>Simulation</h4>

<p>To simulate the model, click the Simulate button in the top toolbar: <img src=\"modelica://BuckConverter/DocumentationFiles/play.svg\" style=\"width:20px\" alt=\"simulate\" /></p>

<h4>Plot the results</h4>

<p>When the simulation is done, a Model plot will automatically be displayed:</p>

<p style=\"text-align: center;\"><img src=\"modelica://BuckConverter/DocumentationFiles/plot.png\" style=\"width:600px\" alt=\"\" /></p>


<h4>Zoom</h4>

<p>The switch is continuously being opened and closed by the <a href=\"modelica://Modelica.Blocks.Sources.BooleanPulse\">boolean pulse</a> supplied to it. This happens so fast that it is hard to discern from the graph.</p>

<p>Zoom in on the graph to explore the ripple caused by the buck converter. To do this, perform the following steps</p>

<ul>
<li>In the Plot Window, position your mouse cursor around 13 V on the Y-axis and 0.009 s.</li>
<li>Draw a small box around the plots (see picture) by clicking and dragging your mouse cursor. When you release the button, you will zoom in on the selected area</li>
<li>To return to the original view, right click anywhere in the Plot Window and select Rescale.</li>
</ul>


<p style=\"text-align: center;\"><img src=\"modelica://BuckConverter/DocumentationFiles/resize.png\" style=\"width:600px\" alt=\"\" /></p>


<h4>Change Parameters</h4>

<p>Changing parameters for the simulation can be done rapidly in Simulation Center. The D parameter determines the duty-ration of the buck converter. This is determined by the relative duration between the closed/on period and the open/off period. The standard value for this parameter is 0.5 which means that 50% of the time, the switch will be closed and the voltage source will be connected to the circuit. The resulting voltage over the load will be 50% of the input voltage.</p>

<p>Try changing the duty-ration of the converter, D and see how this affects the controller:</p>

<ul>
<li>Switch to the Parameter tab to the left in the Experiment Browser.</li>
<li>Scroll down to the D parameter and change its value to 0.75 by typing into the box to the right of the parameter.</li>
<li>Simulate again by following the steps in the Simulation section to see the effects of your changes.</li>
</ul>

<p>You should now see the graph below, note that the Zener regulator is not affected by the parameter change above:</p>

<p style=\"text-align: center;\"><img src=\"modelica://BuckConverter/DocumentationFiles/plot2.png\" style=\"width:600px\" alt=\"\" /></p>

</html>", figures = {Figure(title = "Load voltage Buck converter vs Zener regulator ", identifier = "6eb23", preferred = true, plots = {Plot(curves = {Curve(y = load_BuckConverter.v), Curve(y = load_Zener.v)}, x = Axis(unit = "ms"))}), Figure(title = "Buck converter behavior", identifier = "9b5ed", plots = {Plot(curves = {Curve(y = load_BuckConverter.v), Curve(y = load_Zener.v)}, x = Axis(min = 0.007985104552499202, max = 0.008516085813714526), y = Axis(min = 11.9518475877193, max = 12.13411793372319)), Plot(curves = {Curve(y = booleanPulse.y)}, x = Axis(min = 0.007985104552499202, max = 0.008516085813714526))})}), uses(Modelica(version = "4.0.0")), preferredView = "info", Icon(coordinateSystem(extent = {{-100, -100}, {100, 100}}, preserveAspectRatio = true, initialScale = 0.1, grid = {10, 10}), graphics = {Rectangle(visible = true, lineColor = {111, 0, 0}, fillColor = {255, 0, 0}, fillPattern = FillPattern.HorizontalCylinder, lineThickness = 4, extent = {{-90, -90}, {90, 90}}, radius = 25), Text(visible = true, origin = {12, 20.833}, textColor = {255, 255, 255}, extent = {{-102, -70.833}, {78, 29.167}}, textString = "Ex", fontName = "Arial")}), Diagram(coordinateSystem(extent = {{-120, -95}, {115, 95}}, preserveAspectRatio = true, initialScale = 0.1, grid = {5, 5}), graphics = {Text(visible = true, origin = {-0, 80.677}, extent = {{-26.184, -5.677}, {26.184, 5.677}}, textString = "Buck Converter"), Text(visible = true, origin = {-0, -19.148}, extent = {{-26.991, -5.852}, {26.991, 5.852}}, textString = "Zener Regulator")}));
end BuckConverter;
